var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { __fetch_basic_data } from "../__fetches/__fetch_basic_data";
import { __fetch_following_ids } from '../__fetches/__fetch_following_ids';
import { __fetch_follower_ids } from '../__fetches/__fetch_follower_ids';
import { __fetch_quest_certifications } from "../__fetches/__fetch_quest_certifications";
import { __fetch_topic_skills } from "../__fetches/__fetch_topic_skills";
import { __fetch_programming_languages } from "../__fetches/__fetch_programming_languages";
import { __fetch_achievements } from "../__fetches/__fetch_achievements";
import { Codingame_API_Exeption } from '../Codingamer_Exeption';
function __get_rank_title_threshold(rank) {
    if (rank <= 100)
        return 1;
    if (rank <= 500)
        return 100;
    if (rank <= 2500)
        return 500;
    if (rank <= 5000)
        return 2500;
    if (rank <= 10000)
        return 5000;
    if (rank <= 20000)
        return 10000;
    return 20000;
}
function __get_rank_title_id(rank) {
    if (rank <= 100)
        return 0;
    if (rank <= 500)
        return 1;
    if (rank <= 2500)
        return 2;
    if (rank <= 5000)
        return 3;
    if (rank <= 10000)
        return 4;
    if (rank <= 20000)
        return 5;
    return 6;
}
export class Codingamer {
    constructor(public_handle) {
        this.public_handle = public_handle;
    }
    update_all(abord_signal = AbortSignal.timeout(35000)) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.update_basic_data(abord_signal);
            yield Promise.all([
                this.update_quest_certifications(abord_signal),
                this.update_topic_skills(abord_signal),
                this.update_programming_languages(abord_signal),
                this.update_follower_ids(abord_signal),
                this.update_following_ids(abord_signal),
                this.update_achievements(abord_signal)
            ]);
        });
    }
    update_basic_data(abord_signal = AbortSignal.timeout(5000)) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield __fetch_basic_data(this.public_handle, abord_signal);
            if (!data)
                throw new Codingame_API_Exeption("fetch_basic_data, api_return_null", "fetch_basic_data : api_return_null", "api_return_null", "fetch_basic_data");
            this.pseudo = data.codingamer.pseudo;
            this.id = data.codingamer.userId;
            this.country_id = data.codingamer.countryId;
            this.school_id = data.codingamer.schoolId;
            this.rank = data.codingamer.rank;
            this.rank_title_threshold = __get_rank_title_threshold(this.rank);
            this.rank_title_id = __get_rank_title_id(this.rank);
            this.avatar_id = data.codingamer.avatar;
            this.cover_id = data.codingamer.cover;
            this.company = data.codingamer.company;
            this.city = data.codingamer.city;
            this.level = data.codingamer.level;
            this.xp_cumulative = data.codingamer.xp;
            this.xp = data.codingamer.xp - data.xpThresholds[0].cumulativeXp;
            this.xp_threshold = data.xpThresholds[1].xpThreshold;
            this.category = data.codingamer.category;
            this.codingamer_points = data.codingamerPoints;
            this.achievement_count = data.achievementCount;
        });
    }
    update_quest_certifications(abord_signal = AbortSignal.timeout(5000)) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id)
                throw new Codingame_API_Exeption("user_id undefined, call update_basic_data to update it", "update_quest_certifications : user_id_undefined", "user_id_undefined", "update_quest_certifications");
            this.quest_certifications = yield __fetch_quest_certifications(this.id, abord_signal);
        });
    }
    update_follower_ids(abord_signal = AbortSignal.timeout(5000)) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id)
                throw new Codingame_API_Exeption("user_id undefined, call update_basic_data to update it", "update_follower_ids : user_id_undefined", "user_id_undefined", "update_follower_ids");
            this.follower_ids = yield __fetch_follower_ids(this.id, abord_signal);
        });
    }
    update_following_ids(abord_signal = AbortSignal.timeout(5000)) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id)
                throw new Codingame_API_Exeption("user_id undefined, call update_basic_data to update it", "update_following_ids : user_id_undefined", "user_id_undefined", "update_following_ids");
            this.following_ids = yield __fetch_following_ids(this.id, abord_signal);
        });
    }
    update_topic_skills(abord_signal = AbortSignal.timeout(5000)) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id)
                throw new Codingame_API_Exeption("user_id undefined, call update_basic_data to update it", "update_topic_skills : user_id_undefined", "user_id_undefined", "update_topic_skills");
            this.topic_skills = yield __fetch_topic_skills(this.id, abord_signal);
        });
    }
    update_programming_languages(abord_signal = AbortSignal.timeout(5000)) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id)
                throw new Codingame_API_Exeption("user_id undefined, call update_basic_data to update it", "update_programming_languages, user_id_undefined", "user_id_undefined", "update_programming_languages");
            this.programming_languages = yield __fetch_programming_languages(this.id, abord_signal);
        });
    }
    update_achievements(abord_signal = AbortSignal.timeout(5000)) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id)
                throw new Codingame_API_Exeption("user_id undefined, call update_basic_data to update it", "update_achievements : user_id_undefined", "user_id_undefined", "update_achievements");
            this.achievements = yield __fetch_achievements(this.id, abord_signal);
        });
    }
    get avatar_url() {
        if (!this.avatar_id)
            return undefined;
        return "https://static.codingame.com/servlet/fileservlet?id=" + this.avatar_id;
    }
    get cover_url() {
        if (!this.avatar_id)
            return undefined;
        return "https://static.codingame.com/servlet/fileservlet?id=" + this.cover_id;
    }
}
//# sourceMappingURL=Codingamer.js.map